@@ -247,19 +247,9 @@ struct jump_shot parse_slice_for_double_jump_with_target(double time_remaining,
     struct opti_norm car_to_ball_norm = normalize(car_to_ball);
     Vector direction = car_to_ball_norm.vector;
     double distance = car_to_ball_norm.magnitude;
+    double forward_time = time_remaining - (angle(flatten(direction), flatten(car_forward)) * 0.318);
 
-    double forward_angle = angle(flatten(direction), flatten(car_forward));
-    double backward_angle = Py_MATH_PI - forward_angle;
-
-    double forward_time = time_remaining - (forward_angle * 0.318);
-    double backward_time = time_remaining - (backward_angle * 0.418);
-
-    _Bool forward_flag = forward_time > 0 && (distance / forward_time) < ((car_boost > distance / 100) ? 2275 : 1400);
-    _Bool backward_flag = backward_time > 0 && (distance * 1.05 / backward_time) < 1200;
-
-    r.best_shot_vector = direction;
-
-    if (forward_flag || backward_flag)
+    if (forward_time > 0 && (distance / forward_time) < ((car_boost > distance / 100) ? 2275 : 1400))
     {
         struct post_correction pst_crrctn = correct_for_posts(ball_location, left_target, right_target);
         if (!pst_crrctn.swapped)
@@ -268,12 +258,8 @@ struct jump_shot parse_slice_for_double_jump_with_target(double time_remaining,
             Vector right_vector = normalize(sub(pst_crrctn.right, ball_location)).vector;
             r.best_shot_vector = clamp(direction, left_vector, right_vector);
 
-            if (in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1))
-            {
-                double slope = find_slope(r.best_shot_vector, car_to_ball);
-                if ((forward_flag && slope > 0) || (backward_flag && slope > 0.5))
-                    r.found = 1;
-            }
+            if (in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1) && find_slope(r.best_shot_vector, car_to_ball) > 0)
+                r.found = 1;
         }
     }
 
@@ -289,24 +275,12 @@ struct jump_shot parse_slice_for_double_jump(double time_remaining, double best_
     struct opti_norm car_to_ball_norm = normalize(car_to_ball);
     Vector direction = car_to_ball_norm.vector;
     double distance = car_to_ball_norm.magnitude;
-
-    double forward_angle = angle(flatten(direction), flatten(car_forward));
-    double backward_angle = Py_MATH_PI - forward_angle;
-
-    double forward_time = time_remaining - (forward_angle * 0.318);
-    double backward_time = time_remaining - (backward_angle * 0.418);
-
-    _Bool forward_flag = forward_time > 0 && (distance / forward_time) < ((car_boost > distance / 100) ? 2275 : 1400);
-    _Bool backward_flag = backward_time > 0 && (distance * 1.05 / backward_time) < 1200;
+    double forward_time = time_remaining - (angle(flatten(direction), flatten(car_forward)) * 0.318);
 
     r.best_shot_vector = direction;
 
-    if ((forward_flag || backward_flag) && in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1))
-    {
-        double slope = find_slope(r.best_shot_vector, car_to_ball);
-        if ((forward_flag && slope > 0) || (backward_flag && slope > 0.5))
-            r.found = 1;
-    }
+    if (forward_time > 0 && (distance / forward_time) < ((car_boost > distance / 100) ? 2275 : 1400) && find_slope(r.best_shot_vector, car_to_ball) > 0)
+        r.found = 1;
 
     return r;
 };
